"""Custom scanners for languages not supported by OpenGrep."""

from .sql_crypto_scanner import SQLCryptoScanner
from .html_crypto_scanner import HTMLCryptoScanner
from .apex_crypto_scanner import ApexCryptoScanner
from .elixir_crypto_scanner import ElixirCryptoScanner
from .certificate_crypto_scanner import CertificateCryptoScanner
from .bouncycastle_crypto_scanner import BouncyCastleCryptoScanner
from .paramiko_crypto_scanner import ParamikoCryptoScanner

__all__ = [
    'SQLCryptoScanner', 'HTMLCryptoScanner', 'ApexCryptoScanner',
    'ElixirCryptoScanner', 'CertificateCryptoScanner',
    'BouncyCastleCryptoScanner', 'ParamikoCryptoScanner',
]
