"""
Build Configuration - Development Build
"""

# Development mode is ENABLED for local development
ALLOW_DEV_MODE = True

# Build information
BUILD_TYPE = "development"
BUILD_DATE = None
BUILD_VERSION = None

# Baked-in license server credentials — compiled to .pyd in production builds.
# Env var overrides these (dev / CI).
LICENSE_API_KEY = "lsrv_live_952ac958c20c8869239fe2917c17c15fcf6764590fb43671620c5bca581dfe26"
LICENSE_SERVER_URL = "https://license.cerebion.com"
